/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { select } from "../../util";
import { CalibrationLaboratoryType, ContactType, DCCDocument } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:calibrationLaboratory";
const xpath = {
  contact: {
    eMail: `string(${base}/dcc:eMail)`,
  },
  cryptElectronicSeal: `string(${base}/dcc:cryptElectronicSeal)`,
  cryptElectronicSignature: `string(${base}/dcc:cryptElectronicSignature)`,
  cryptElectronicTimeStamp: `string(${base}/dcc:cryptElectronicTimeStamp)`,
};

describe("Features_DCC_v3.2.0: CalibrationLaboratory", () => {
  let dcc: DCCDocument, dom, calibrationLaboratory: CalibrationLaboratoryType, contact: ContactType;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    calibrationLaboratory = dcc.digitalCalibrationCertificate.administrativeData.calibrationLaboratory;
    contact = calibrationLaboratory.contact;
  });

  test("eMail should not be defined", () => {
    expect(contact.eMail).toBeUndefined();
  });

  test("should get correct cryptElectronicSeal from XML", () => {
    expect(calibrationLaboratory.cryptElectronicSeal._text).toBe(select(xpath.cryptElectronicSeal, dom));
  });

  test("should get correct cryptElectronicSignature from XML", () => {
    expect(calibrationLaboratory.cryptElectronicSignature._text).toBe(select(xpath.cryptElectronicSignature, dom));
  });

  test("should get correct cryptElectronicTimeStamp from XML", () => {
    expect(calibrationLaboratory.cryptElectronicTimeStamp._text).toBe(select(xpath.cryptElectronicTimeStamp, dom));
  });
});
