/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument } from "../../../src";
import { expect } from "vitest";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:statements";
const statement_validXmlList_base = `${base}/dcc:statement[1]`;
const statement_validXmlList_statement_validXmlList_base = `${statement_validXmlList_base}/dcc:data/dcc:quantity/dcc:measurementMetaData`;
const xpath = {
  statement_validXmlList: {
    name: {
      content: `${statement_validXmlList_base}/dcc:name/dcc:content`,
    },
    description: {
      content: `${statement_validXmlList_base}/dcc:description/dcc:content`,
    },
    data: {
      quantity: {
        measurementMetaData: {
          metaData1: {
            declaration: {
              content: `${statement_validXmlList_statement_validXmlList_base}/dcc:metaData[1]/dcc:declaration/dcc:content`,
            },
            validXMLList: `string(${statement_validXmlList_statement_validXmlList_base}/dcc:metaData[1]/dcc:validXMLList)`,
          },
          metaData2: {
            declaration: {
              content: `${statement_validXmlList_statement_validXmlList_base}/dcc:metaData[2]/dcc:declaration/dcc:content`,
            },
            validXMLList: `string(${statement_validXmlList_statement_validXmlList_base}/dcc:metaData[2]/dcc:validXMLList)`,
          },
        },
      },
    },
  },
};

describe("Features_DCC_v3.2.0: StatementMetaDataType", () => {
  let dcc: DCCDocument, statement_validXmlList, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    statement_validXmlList = dcc.digitalCalibrationCertificate.administrativeData.statements.statement[0];
  });

  test("should get correct statement 1 name content from XML", () => {
    const expected = <Element[]>select(xpath.statement_validXmlList.name.content, dom);
    expect(toTextArr(statement_validXmlList.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct statement 1 description content from XML", () => {
    const expected = <Element[]>select(xpath.statement_validXmlList.description.content, dom);
    expect(toTextArr(statement_validXmlList.description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct statement 1 metaData 1 declaration content from XML", () => {
    const expected = <Element[]>select(xpath.statement_validXmlList.data.quantity.measurementMetaData.metaData1.declaration.content, dom);
    expect(toTextArr(statement_validXmlList.data.quantity[0].measurementMetaData.metaData[0].declaration.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct statement 1 metaData 1 validXMLList from XML", () => {
    expect(statement_validXmlList.data.quantity[0].measurementMetaData.metaData[0].validXMLList._text).toBe(
      select(xpath.statement_validXmlList.data.quantity.measurementMetaData.metaData1.validXMLList, dom),
    );
  });

  test("should get correct statement 1 metaData 2 declaration content from XML", () => {
    const expected = <Element[]>select(xpath.statement_validXmlList.data.quantity.measurementMetaData.metaData2.declaration.content, dom);
    expect(toTextArr(statement_validXmlList.data.quantity[0].measurementMetaData.metaData[1].declaration.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct statement 1 metaData 2 validXMLList from XML", () => {
    expect(statement_validXmlList.data.quantity[0].measurementMetaData.metaData[1].validXMLList._text).toBe(
      select(xpath.statement_validXmlList.data.quantity.measurementMetaData.metaData2.validXMLList, dom),
    );
  });

  /* TODO: setters */
});
