/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { ByteDataType, DCCDocument, QuantityType } from "../../../src";
import { select } from "../../util";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]";
const file_base = `${base}/dcc:description/dcc:file`;
const xpath = {
  description: {
    file: {
      refId: `string(${file_base}//@refId)`,
      refType: `string(${file_base}//@refType)`,
    },
  },
  charsXMLList: `string(${base}/dcc:results/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:charsXMLList)`,
};

describe("Features_DCC_v3.2.0: MeasurementResult", () => {
  let dcc: DCCDocument, dom, file: ByteDataType, quantity: QuantityType;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    file = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].description.file[0];
    quantity = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].results.result[0].data.quantity[0];
  });

  // region dcc:file / ByteDataType
  test("should get correct file refId from XML", () => {
    expect(file._attr.refId).toBe(select(xpath.description.file.refId, dom));
  });

  test("should get correct file refType from XML", () => {
    expect(file._attr.refType).toBe(select(xpath.description.file.refType, dom));
  });
  // endregion

  // region dcc:charsXMLList
  test("should get correct charsXMLList from XML", () => {
    expect(quantity.charsXMLList._text).toBe(select(xpath.charsXMLList, dom));
  });
  // endregion
});
