/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, MeasuringEquipmentType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:measuringEquipments/dcc:measuringEquipment[1]";
const xpath = {
  measuringEquipments: {
    measuringEquipment: {
      name: {
        content: `${base}/dcc:name/dcc:content`,
      },
      identifications: {
        identification: {
          issuer: `string(${base}/dcc:identifications/dcc:identification[1]/dcc:issuer)`,
          value: `string(${base}/dcc:identifications/dcc:identification[1]/dcc:value)`,
        },
      },
      refType: `string(${base}//@refType)`,
    },
  },
};

describe("GP_DCC_Temperature_Simplified: MeasuringEquipmentType", () => {
  let dcc: DCCDocument, measuringEquipment: MeasuringEquipmentType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    measuringEquipment = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].measuringEquipments.measuringEquipment[0];
  });

  test("should get correct measurement result name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measuringEquipments.measuringEquipment.name.content, dom);
    expect(toTextArr(measuringEquipment.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct measuring equipment 1 identification issuer from XML", () => {
    expect(measuringEquipment.identifications.identification[0].issuer._text).toBe(
      select(xpath.measuringEquipments.measuringEquipment.identifications.identification.issuer, dom),
    );
  });

  test("should get correct measuring equipment 1 identification value from XML", () => {
    expect(measuringEquipment.identifications.identification[0].value._text).toBe(
      select(xpath.measuringEquipments.measuringEquipment.identifications.identification.value, dom),
    );
  });

  test("should get correct measuring equipment 1 refType from XML", () => {
    expect(measuringEquipment._attr.refType).toBe(select(xpath.measuringEquipments.measuringEquipment.refType, dom));
  });

  /* TODO: setters */
});
