/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Test_DCC_Minimal.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ContactType, DCCDocument, LocationType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:customer";
const xpath = {
  customer: {
    name: {
      content: `${base}/dcc:name/dcc:content`,
    },
    location: {
      city: `${base}/dcc:location/dcc:city[1]`,
    },
  },
};

describe("Test_DCC_Minimal: ContactType", () => {
  let dcc: DCCDocument, customer: ContactType, location: LocationType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    customer = dcc.digitalCalibrationCertificate.administrativeData.customer;
    location = customer.location; /* TODO: check iff this variable is used anywhere */
  });

  test("should get correct customer name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.customer.name.content, dom);
    expect(toTextArr(customer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct customer location city from XML", () => {
    const expected = <Element[]>select(xpath.customer.location.city, dom);
    expect(customer.location.city[0]._text).toEqual(toTextContentArr(expected)[0]);
  });

  /* TODO: setters */
});
