import { ContactNotStrictType, ContactType, DCCDocument } from "../../../../src";
import { select, toTextArr, toTextContentArr, undefinedIfEmpty } from "../../../util";

export const testContactType = (base: string, contactTypeFn: (dcc: DCCDocument) => ContactType | ContactNotStrictType) => {
  const xpath = {
    customer: {
      name: {
        content: `${base}/dcc:name/dcc:content`,
      },
      email: `string(${base}/dcc:eMail)`,
      phone: `string(${base}/dcc:phone)`,
      fax: `string(${base}/dcc:fax)`,
      location: {
        city: `${base}/dcc:location/dcc:city[1]`,
        countryCode: `${base}/dcc:location/dcc:countryCode[1]`,
        postCode: `${base}/dcc:location/dcc:postCode[1]`,
        postBoxOffice: `${base}/dcc:location/dcc:postBoxOffice[1]`,
        state: `${base}/dcc:location/dcc:state[1]`,
        street: `${base}/dcc:location/dcc:street[1]`,
        streetNo: `${base}/dcc:location/dcc:streetNo[1]`,
        further: `${base}/dcc:location/dcc:further[1]/dcc:content`,
        positionCoordinates: `${base}/dcc:location/dcc:positionCoordinates[1]`,
      },
      descriptionData: `${base}/dcc:descriptionData`,
      _id: `${base}/@id`,
    },
  };

  describe("ContactType", () => {
    let dcc: DCCDocument, contactType: ContactType | ContactNotStrictType, dom;

    beforeEach(() => {
      ({ dcc, dom } = recreateEnv());
      contactType = contactTypeFn(dcc);
    });

    test("should get correct customer name content from XML", () => {
      // get expected list from example xml
      const expected = <Element[]>select(xpath.customer.name.content, dom);
      expect(toTextArr(contactType.name.content)).toEqual(toTextContentArr(expected));
    });

    test("should get correct customer email address from XML", () => {
      expect(contactType.eMail?._text).toBe(undefinedIfEmpty(select(xpath.customer.email, dom)));
    });

    test("should get correct customer location city from XML", () => {
      const expected = <Element[]>select(xpath.customer.location.city, dom);
      expect(contactType.location?.city[0]._text).toEqual(toTextContentArr(expected)[0]);
    });

    test("should get correct customer location county code from XML", () => {
      const expected = <Element[]>select(xpath.customer.location.countryCode, dom);
      expect(contactType.location?.countryCode[0]._text).toEqual(toTextContentArr(expected)[0]);
    });

    test("should get correct customer location post code from XML", () => {
      const expected = <Element[]>select(xpath.customer.location.postCode, dom);
      expect(contactType.location?.postCode[0]._text).toEqual(toTextContentArr(expected)[0]);
    });

    test("should get correct customer location further from XML", () => {
      const expected = <Element[]>select(xpath.customer.location.further, dom);

      for (let i = 0; i < expected.length; i++) {
        expect(contactType.location?.further[0].content[i]._text).toBe(expected[i].textContent);
      }
    });

    /* TODO: setters */
  });
};
