import { DCCDocument, StatementMetaDataType } from "../../../../src";
import { select, toTextArr, toTextContentArr, undefinedIfEmpty } from "../../../util";
import { testContactType } from "./ContactType";
import { testDataType } from "./DataType";

export const testStatementMetaDataType = (name, base: string, statementMetaDataTypeFn: (dcc: DCCDocument) => StatementMetaDataType) => {
  const xpath = {
    norm: `${base}/dcc:norm`,
    reference: `${base}/dcc:reference`,
    declaration: {
      content: `${base}/dcc:declaration/dcc:content`,
    },
    conformity: `string(${base}/dcc:conformity)`,
    date: `string(${base}/dcc:date)`,
    respAuthority: `${base}/dcc:respAuthority`,
    data: `${base}/dcc:data`,

    refType: `string(${base}/@refType)`,
  };

  describe(`StatementMetaDataType ${name}`, () => {
    let dcc: DCCDocument, statementMetaDataType: StatementMetaDataType, dom;
    ({ dcc, dom } = recreateEnv());

    beforeEach(() => {
      ({ dcc, dom } = recreateEnv());
      statementMetaDataType = statementMetaDataTypeFn(dcc);
    });

    const hasContact = <boolean>select(`boolean(${xpath.respAuthority})`, dom);
    if (hasContact) {
      testContactType(xpath.respAuthority, (dcc) => statementMetaDataTypeFn(dcc).respAuthority);
    }

    const hasData = <boolean>select(`boolean(${xpath.data})`, dom);
    if (hasData) {
      testDataType(xpath.data, (dcc) => statementMetaDataTypeFn(dcc).data);
    }

    test("should get correct statement declaration content from XML", () => {
      const expected = <Element[]>select(xpath.declaration.content, dom);
      expect(toTextArr(statementMetaDataType.declaration?.content)).toEqual(toTextContentArr(expected));
    });

    test("should get correct statement norm model from XML", () => {
      const expected = <Element[]>select(xpath.norm, dom);
      expect(toTextArr(statementMetaDataType.norm)).toEqual(toTextContentArr(expected));
    });

    test("should get correct statement reference from XML", () => {
      const expected = <Element[]>select(xpath.reference, dom);
      expect(toTextArr(statementMetaDataType.reference)).toEqual(toTextContentArr(expected));
    });

    test("should get correct statement refType from XML", () => {
      const expected = select(xpath.refType, dom);
      expect(statementMetaDataType._attr.refType).toBe(undefinedIfEmpty(expected));
    });

    test("should get correct statement conformity from XML", () => {
      const expected = select(xpath.conformity, dom);
      expect(statementMetaDataType.conformity?._text).toBe(undefinedIfEmpty(expected));
    });

    test("should get correct statement date from XML", () => {
      const expected = select(xpath.date, dom);
      expect(statementMetaDataType.date?._text).toBe(undefinedIfEmpty(expected));
    });

    /* TODO: setters */
  });
};
